@@ -55,6 +55,12 @@ class Console(cmd.Cmd):
         cmd.Cmd.__init__(self)
         self.__options = options
         options.addOptionChangedCallback(self.optionChanged)
+        import readline
+        old_delims = readline.get_completer_delims() # <-
+        old_delims = old_delims.replace('-', '')
+        old_delims = old_delims.replace('/', '')
+        readline.set_completer_delims(old_delims) # <-
+
         self.__binary = None
         self.__binaries = []
         self.__gadgets = {}
@@ -81,7 +87,10 @@ class Console(cmd.Cmd):
         self.__handleOptions(self.__options)
 
     def __loadFile(self, file):
-        self.__binary = Loader.open(file, self.__options.raw, self.__options.arch)
+        try:
+            self.__binary = Loader.open(file, self.__options.raw, self.__options.arch)
+        except BaseException as e:
+            raise RopperError(e)
         self.__binaries.append(self.__binary)
         self.__binary.imageBase = self.__options.I
         if self.__options.arch:
@@ -480,6 +489,18 @@ class Console(cmd.Cmd):
             self.__loadFile(text)
             self.__printInfo('File loaded.')
 
+    def complete_file(self, text, line, begidx, endidx):
+        file = text
+        cwd = '.'
+        path = ''
+        if '/' in file:
+            cwd = file[:file.rindex('/')+1]
+            file = file[file.rindex('/')+1:]
+            path = cwd
+
+        return [path+i for i in os.listdir(cwd) if i.startswith(file)]
+        
+
     def help_file(self):
         self.__printHelpText('file <file>|<idx>', 'file - loads a file\nidx - select this loaded file')
 
@@ -576,8 +597,8 @@ nx\t- Clears the NX-Flag (ELF|PE)"""
             text = text[len(match.group(0)):].strip()
         for binary in self.__binaries:
             self.__cprinter.printInfo('Search in gadgets of file \'%s\'' % binary.fileName)
-            if self.binary in self.__gadgets:
-                self.__printGadgets(self.__search(self.__gadgets[self.binary], text, qual))
+            if binary in self.__gadgets:
+                self.__printGadgets(self.__search(self.__gadgets[binary], text, qual))
 
     def help_search(self):
         desc = 'search gadgets.\n\n'
